@@ -7,6 +7,25 @@ execution_log = log.getChild("execution")
 SEPARATOR = "------"
 
 
+def str_to_bool(val: str) -> bool:
+    clean_val = val.lower().strip()
+    if clean_val in ("yes", "y", "true", "t", "1"):
+        return True
+    if clean_val in ("no", "n", "false", "f", "0"):
+        return False
+    raise ValueError(f"Could not parse boolean from '{val}'")
+
+
+def yes_or_no(explanation: str) -> bool:
+    while True:
+        raw_answer = input(f"{explanation}. Are you sure you want to continue? (Y/n): ")
+        try:
+            answer = str_to_bool(raw_answer)
+            return answer
+        except ValueError:
+            pass
+
+
 def execute_shell(
     command: str,
     args: Iterable = None,
